## Picsellia SDK

Picsellia Python SDK is an open source library that allows external python client to connect to Picsellia platform.
For getting started, initalize a client with
```
client = Client(api_token=<your api token>)
```